@@ -28,7 +28,6 @@ ResponseData = TypeVar('ResponseData')
 class BackendError(Exception):
     pass
 
-
 @dataclass(frozen=True)
 class BulkUploadPayload:
     data:    bytes
@@ -68,10 +67,12 @@ class DeleteDetectionsParams:
     dry_run: bool
     include_saved_queries: bool
 
+
 @dataclass(frozen=True)
 class ListSchemasParams:
     is_managed: bool
 
+
 @dataclass(frozen=True)
 class UpdateManagedSchemaParams:
     description: str
@@ -80,6 +81,7 @@ class UpdateManagedSchemaParams:
     revision: int
     spec: str
 
+
 @dataclass(frozen=True)
 class BulkUploadStatistics:
     new: int
@@ -107,6 +109,7 @@ class DeleteDetectionsResponse:
     ids: List[str]
     saved_query_names: List[str]
 
+
 # pylint: disable=too-many-instance-attributes
 @dataclass(frozen=True)
 class ManagedSchema:
@@ -119,14 +122,29 @@ class ManagedSchema:
     spec: str
     updated_at: str
 
+
 @dataclass(frozen=True)
 class ListManagedSchemasResponse:
     schemas: List[ManagedSchema]
 
+
 @dataclass(frozen=True)
 class UpdateManagedSchemaResponse:
     schema: ManagedSchema
 
+
+@dataclass(frozen=True)
+class ConfigSDKBulkUploadParams:
+    content: str
+
+
+@dataclass(frozen=True)
+class ConfigSDKBulkUploadResponse:
+    rules: BulkUploadStatistics
+    policies: BulkUploadStatistics
+    queries: BulkUploadStatistics
+
+
 class Client(ABC):
 
     @abstractmethod
@@ -152,3 +170,7 @@ class Client(ABC):
     @abstractmethod
     def update_managed_schema(self, params: UpdateManagedSchemaParams) -> BackendResponse[Any]:
         pass
+
+    @abstractmethod
+    def configsdk_bulk_upload(self, params: ConfigSDKBulkUploadParams) -> BackendResponse[ConfigSDKBulkUploadResponse]:
+        pass
