@@ -8,7 +8,9 @@ from panther_analysis_tool.backend.client import (
     BackendCheckResponse,
     DeleteDetectionsParams,
     DeleteSavedQueriesParams,
-    ListSchemasParams, UpdateManagedSchemaParams,
+    ListSchemasParams,
+    UpdateManagedSchemaParams,
+    ConfigSDKBulkUploadParams,
 )
 
 
@@ -30,3 +32,6 @@ class MockBackend(BackendClient):
 
     def delete_detections(self, params: DeleteDetectionsParams) -> BackendResponse[Any]:
         pass
+
+    def configsdk_bulk_upload(self, params: ConfigSDKBulkUploadParams) -> BackendResponse[Any]:
+        pass
